==> rguatlas4k.db_2.2.5.tar.gz: rguatlas4k.db/man/rguatlas4k_dbconn.Rd <==
\name{rguatlas4k_dbconn}

\alias{rguatlas4k_dbconn}
\alias{rguatlas4k_dbfile}
\alias{rguatlas4k_dbschema}
\alias{rguatlas4k_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  rguatlas4k_dbconn()
  rguatlas4k_dbfile()
  rguatlas4k_dbschema(file="", show.indices=FALSE)
  rguatlas4k_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{rguatlas4k_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{rguatlas4k_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{rguatlas4k_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{rguatlas4k_dbschema} prints the schema definition of the
  package annotation DB.

  \code{rguatlas4k_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{rguatlas4k_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{rguatlas4k_dbfile}: a character string with the path to the
  package annotation DB.

  \code{rguatlas4k_dbschema}: none (invisible \code{NULL}).

  \code{rguatlas4k_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(rguatlas4k_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by rguatlas4k_dbconn() was created with:
  dbConnect(SQLite(), dbname=rguatlas4k_dbfile(), cache_size=64000, synchronous=0)

  rguatlas4k_dbschema()

  rguatlas4k_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> rguatlas4k.db_2.8.1.tar.gz: rguatlas4k.db/man/rguatlas4k_dbconn.Rd <==

\name{rguatlas4k_dbconn}

\alias{rguatlas4k_dbconn}
\alias{rguatlas4k_dbfile}
\alias{rguatlas4k_dbschema}
\alias{rguatlas4k_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  rguatlas4k_dbconn()
  rguatlas4k_dbfile()
  rguatlas4k_dbschema(file="", show.indices=FALSE)
  rguatlas4k_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{rguatlas4k_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{rguatlas4k_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{rguatlas4k_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{rguatlas4k_dbschema} prints the schema definition of the
  package annotation DB.

  \code{rguatlas4k_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{rguatlas4k_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{rguatlas4k_dbfile}: a character string with the path to the
  package annotation DB.

  \code{rguatlas4k_dbschema}: none (invisible \code{NULL}).

  \code{rguatlas4k_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(rguatlas4k_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by rguatlas4k_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=rguatlas4k_dbfile(), cache_size=64000,
  synchronous=0)

  rguatlas4k_dbschema()

  rguatlas4k_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
